Class: Aws::ApplicationDiscoveryService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ApplicationDiscoveryService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-applicationdiscoveryservice/client.rb
Overview
An API client for ApplicationDiscoveryService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ApplicationDiscoveryService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_configuration_items_to_application(params = {}) ⇒ Struct
Associates one or more configuration items with an application.
-
#batch_delete_agents(params = {}) ⇒ Types::BatchDeleteAgentsResponse
Deletes one or more agents or collectors as specified by ID.
-
#batch_delete_import_data(params = {}) ⇒ Types::BatchDeleteImportDataResponse
Deletes one or more import tasks, each identified by their import ID.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application with the given name and description.
-
#create_tags(params = {}) ⇒ Struct
Creates one or more tags for configuration items.
-
#delete_applications(params = {}) ⇒ Struct
Deletes a list of applications and their associations with configuration items.
-
#delete_tags(params = {}) ⇒ Struct
Deletes the association between configuration items and one or more tags.
-
#describe_agents(params = {}) ⇒ Types::DescribeAgentsResponse
Lists agents or collectors as specified by ID or other filters.
-
#describe_batch_delete_configuration_task(params = {}) ⇒ Types::DescribeBatchDeleteConfigurationTaskResponse
Takes a unique deletion task identifier as input and returns metadata about a configuration deletion task.
-
#describe_configurations(params = {}) ⇒ Types::DescribeConfigurationsResponse
Retrieves attributes for a list of configuration item IDs.
-
#describe_continuous_exports(params = {}) ⇒ Types::DescribeContinuousExportsResponse
Lists exports as specified by ID.
-
#describe_export_configurations(params = {}) ⇒ Types::DescribeExportConfigurationsResponse
‘DescribeExportConfigurations` is deprecated.
-
#describe_export_tasks(params = {}) ⇒ Types::DescribeExportTasksResponse
Retrieve status of one or more export tasks.
-
#describe_import_tasks(params = {}) ⇒ Types::DescribeImportTasksResponse
Returns an array of import tasks for your account, including status information, times, IDs, the Amazon S3 Object URL for the import file, and more.
-
#describe_tags(params = {}) ⇒ Types::DescribeTagsResponse
Retrieves a list of configuration items that have tags as specified by the key-value pairs, name and value, passed to the optional parameter ‘filters`.
-
#disassociate_configuration_items_from_application(params = {}) ⇒ Struct
Disassociates one or more configuration items from an application.
-
#export_configurations(params = {}) ⇒ Types::ExportConfigurationsResponse
Deprecated.
-
#get_discovery_summary(params = {}) ⇒ Types::GetDiscoverySummaryResponse
Retrieves a short summary of discovered assets.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Retrieves a list of configuration items as specified by the value passed to the required parameter ‘configurationType`.
-
#list_server_neighbors(params = {}) ⇒ Types::ListServerNeighborsResponse
Retrieves a list of servers that are one network hop away from a specified server.
-
#start_batch_delete_configuration_task(params = {}) ⇒ Types::StartBatchDeleteConfigurationTaskResponse
Takes a list of configurationId as input and starts an asynchronous deletion task to remove the configurationItems.
-
#start_continuous_export(params = {}) ⇒ Types::StartContinuousExportResponse
Start the continuous flow of agent’s discovered data into Amazon Athena.
-
#start_data_collection_by_agent_ids(params = {}) ⇒ Types::StartDataCollectionByAgentIdsResponse
Instructs the specified agents to start collecting data.
-
#start_export_task(params = {}) ⇒ Types::StartExportTaskResponse
Begins the export of a discovered data report to an Amazon S3 bucket managed by Amazon Web Services.
-
#start_import_task(params = {}) ⇒ Types::StartImportTaskResponse
Starts an import task, which allows you to import details of your on-premises environment directly into Amazon Web Services Migration Hub without having to use the Amazon Web Services Application Discovery Service (Application Discovery Service) tools such as the Amazon Web Services Application Discovery Service Agentless Collector or Application Discovery Agent.
-
#stop_continuous_export(params = {}) ⇒ Types::StopContinuousExportResponse
Stop the continuous flow of agent’s discovered data into Amazon Athena.
-
#stop_data_collection_by_agent_ids(params = {}) ⇒ Types::StopDataCollectionByAgentIdsResponse
Instructs the specified agents to stop collecting data.
-
#update_application(params = {}) ⇒ Struct
Updates metadata about an application.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1865 1866 1867 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1865 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1868 1869 1870 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1868 def errors_module Errors end |
Instance Method Details
#associate_configuration_items_to_application(params = {}) ⇒ Struct
Associates one or more configuration items with an application.
505 506 507 508 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 505 def associate_configuration_items_to_application(params = {}, = {}) req = build_request(:associate_configuration_items_to_application, params) req.send_request() end |
#batch_delete_agents(params = {}) ⇒ Types::BatchDeleteAgentsResponse
Deletes one or more agents or collectors as specified by ID. Deleting an agent or collector does not delete the previously discovered data. To delete the data collected, use ‘StartBatchDeleteConfigurationTask`.
541 542 543 544 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 541 def batch_delete_agents(params = {}, = {}) req = build_request(:batch_delete_agents, params) req.send_request() end |
#batch_delete_import_data(params = {}) ⇒ Types::BatchDeleteImportDataResponse
Deletes one or more import tasks, each identified by their import ID. Each import task has a number of records that can identify servers or applications.
Amazon Web Services Application Discovery Service has built-in matching logic that will identify when discovered servers match existing entries that you’ve previously discovered, the information for the already-existing discovered server is updated. When you delete an import task that contains records that were used to match, the information in those matched records that comes from the deleted records will also be deleted.
585 586 587 588 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 585 def batch_delete_import_data(params = {}, = {}) req = build_request(:batch_delete_import_data, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1838 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ApplicationDiscoveryService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-applicationdiscoveryservice' context[:gem_version] = '1.102.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an application with the given name and description.
619 620 621 622 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 619 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_tags(params = {}) ⇒ Struct
Creates one or more tags for configuration items. Tags are metadata that help you categorize IT assets. This API accepts a list of multiple configuration items.
Do not store sensitive information (like personal data) in tags.
656 657 658 659 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 656 def (params = {}, = {}) req = build_request(:create_tags, params) req.send_request() end |
#delete_applications(params = {}) ⇒ Struct
Deletes a list of applications and their associations with configuration items.
677 678 679 680 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 677 def delete_applications(params = {}, = {}) req = build_request(:delete_applications, params) req.send_request() end |
#delete_tags(params = {}) ⇒ Struct
Deletes the association between configuration items and one or more tags. This API accepts a list of multiple configuration items.
711 712 713 714 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 711 def (params = {}, = {}) req = build_request(:delete_tags, params) req.send_request() end |
#describe_agents(params = {}) ⇒ Types::DescribeAgentsResponse
Lists agents or collectors as specified by ID or other filters. All agents/collectors associated with your user can be listed if you call ‘DescribeAgents` as is without passing any parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
783 784 785 786 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 783 def describe_agents(params = {}, = {}) req = build_request(:describe_agents, params) req.send_request() end |
#describe_batch_delete_configuration_task(params = {}) ⇒ Types::DescribeBatchDeleteConfigurationTaskResponse
Takes a unique deletion task identifier as input and returns metadata about a configuration deletion task.
826 827 828 829 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 826 def describe_batch_delete_configuration_task(params = {}, = {}) req = build_request(:describe_batch_delete_configuration_task, params) req.send_request() end |
#describe_configurations(params = {}) ⇒ Types::DescribeConfigurationsResponse
Retrieves attributes for a list of configuration item IDs.
<note markdown=“1”> All of the supplied IDs must be for the same asset type from one of the following:
* server
-
application
-
process
-
connection
Output fields are specific to the asset type specified. For example,
the output for a server configuration item includes a list of attributes about the server, such as host name, operating system, number of network cards, etc.
For a complete list of outputs for each asset type, see [Using the
DescribeConfigurations Action] in the *Amazon Web Services Application Discovery Service User Guide*.
</note>
880 881 882 883 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 880 def describe_configurations(params = {}, = {}) req = build_request(:describe_configurations, params) req.send_request() end |
#describe_continuous_exports(params = {}) ⇒ Types::DescribeContinuousExportsResponse
Lists exports as specified by ID. All continuous exports associated with your user can be listed if you call ‘DescribeContinuousExports` as is without passing any parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
930 931 932 933 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 930 def describe_continuous_exports(params = {}, = {}) req = build_request(:describe_continuous_exports, params) req.send_request() end |
#describe_export_configurations(params = {}) ⇒ Types::DescribeExportConfigurationsResponse
‘DescribeExportConfigurations` is deprecated. Use [DescribeExportTasks], instead.
[1]: docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeExportTasks.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
982 983 984 985 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 982 def describe_export_configurations(params = {}, = {}) req = build_request(:describe_export_configurations, params) req.send_request() end |
#describe_export_tasks(params = {}) ⇒ Types::DescribeExportTasksResponse
Retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1051 1052 1053 1054 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1051 def describe_export_tasks(params = {}, = {}) req = build_request(:describe_export_tasks, params) req.send_request() end |
#describe_import_tasks(params = {}) ⇒ Types::DescribeImportTasksResponse
Returns an array of import tasks for your account, including status information, times, IDs, the Amazon S3 Object URL for the import file, and more.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1113 1114 1115 1116 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1113 def describe_import_tasks(params = {}, = {}) req = build_request(:describe_import_tasks, params) req.send_request() end |
#describe_tags(params = {}) ⇒ Types::DescribeTagsResponse
Retrieves a list of configuration items that have tags as specified by the key-value pairs, name and value, passed to the optional parameter ‘filters`.
There are three valid tag filter names:
-
tagKey
-
tagValue
-
configurationId
Also, all configuration items associated with your user that have tags can be listed if you call ‘DescribeTags` as is without passing any parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1179 1180 1181 1182 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1179 def (params = {}, = {}) req = build_request(:describe_tags, params) req.send_request() end |
#disassociate_configuration_items_from_application(params = {}) ⇒ Struct
Disassociates one or more configuration items from an application.
1204 1205 1206 1207 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1204 def disassociate_configuration_items_from_application(params = {}, = {}) req = build_request(:disassociate_configuration_items_from_application, params) req.send_request() end |
#export_configurations(params = {}) ⇒ Types::ExportConfigurationsResponse
Deprecated. Use ‘StartExportTask` instead.
Exports all discovered configuration data to an Amazon S3 bucket or an application that enables you to view and evaluate the data. Data includes tags and tag associations, processes, connections, servers, and system performance. This API returns an export ID that you can query using the DescribeExportConfigurations API. The system imposes a limit of two configuration exports in six hours.
1228 1229 1230 1231 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1228 def export_configurations(params = {}, = {}) req = build_request(:export_configurations, params) req.send_request() end |
#get_discovery_summary(params = {}) ⇒ Types::GetDiscoverySummaryResponse
Retrieves a short summary of discovered assets.
This API operation takes no request parameters and is called as is at the command prompt as shown in the example.
1286 1287 1288 1289 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1286 def get_discovery_summary(params = {}, = {}) req = build_request(:get_discovery_summary, params) req.send_request() end |
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Retrieves a list of configuration items as specified by the value passed to the required parameter ‘configurationType`. Optional filtering may be applied to refine search results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1369 1370 1371 1372 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1369 def list_configurations(params = {}, = {}) req = build_request(:list_configurations, params) req.send_request() end |
#list_server_neighbors(params = {}) ⇒ Types::ListServerNeighborsResponse
Retrieves a list of servers that are one network hop away from a specified server.
1427 1428 1429 1430 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1427 def list_server_neighbors(params = {}, = {}) req = build_request(:list_server_neighbors, params) req.send_request() end |
#start_batch_delete_configuration_task(params = {}) ⇒ Types::StartBatchDeleteConfigurationTaskResponse
Takes a list of configurationId as input and starts an asynchronous deletion task to remove the configurationItems. Returns a unique deletion task identifier.
1459 1460 1461 1462 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1459 def start_batch_delete_configuration_task(params = {}, = {}) req = build_request(:start_batch_delete_configuration_task, params) req.send_request() end |
#start_continuous_export(params = {}) ⇒ Types::StartContinuousExportResponse
Start the continuous flow of agent’s discovered data into Amazon Athena.
1486 1487 1488 1489 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1486 def start_continuous_export(params = {}, = {}) req = build_request(:start_continuous_export, params) req.send_request() end |
#start_data_collection_by_agent_ids(params = {}) ⇒ Types::StartDataCollectionByAgentIdsResponse
Instructs the specified agents to start collecting data.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1522 def start_data_collection_by_agent_ids(params = {}, = {}) req = build_request(:start_data_collection_by_agent_ids, params) req.send_request() end |
#start_export_task(params = {}) ⇒ Types::StartExportTaskResponse
Begins the export of a discovered data report to an Amazon S3 bucket managed by Amazon Web Services.
<note markdown=“1”> Exports might provide an estimate of fees and savings based on certain information that you provide. Fee estimates do not include any taxes that might apply. Your actual fees and savings depend on a variety of factors, including your actual usage of Amazon Web Services services, which might vary from the estimates provided in this report.
</note>
If you do not specify ‘preferences` or `agentIds` in the filter, a summary of all servers, applications, tags, and performance is generated. This data is an aggregation of all server data collected through on-premises tooling, file import, application grouping and applying tags.
If you specify ‘agentIds` in a filter, the task exports up to 72 hours of detailed data collected by the identified Application Discovery Agent, including network, process, and performance details. A time range for exported agent data may be set by using `startTime` and `endTime`. Export of detailed agent data is limited to five concurrently running exports. Export of detailed agent data is limited to two exports per day.
If you enable ‘ec2RecommendationsPreferences` in `preferences` , an Amazon EC2 instance matching the characteristics of each server in Application Discovery Service is generated. Changing the attributes of the `ec2RecommendationsPreferences` changes the criteria of the recommendation.
1635 1636 1637 1638 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1635 def start_export_task(params = {}, = {}) req = build_request(:start_export_task, params) req.send_request() end |
#start_import_task(params = {}) ⇒ Types::StartImportTaskResponse
Starts an import task, which allows you to import details of your on-premises environment directly into Amazon Web Services Migration Hub without having to use the Amazon Web Services Application Discovery Service (Application Discovery Service) tools such as the Amazon Web Services Application Discovery Service Agentless Collector or Application Discovery Agent. This gives you the option to perform migration assessment and planning directly from your imported data, including the ability to group your devices as applications and track their migration status.
To start an import request, do this:
-
Download the specially formatted comma separated value (CSV) import template, which you can find here: [s3.us-west-2.amazonaws.com/templates-7cffcf56-bd96-4b1c-b45b-a5b42f282e46/import_template.csv][1].
-
Fill out the template with your server and application data.
-
Upload your import file to an Amazon S3 bucket, and make a note of it’s Object URL. Your import file must be in the CSV format.
-
Use the console or the ‘StartImportTask` command with the Amazon Web Services CLI or one of the Amazon Web Services SDKs to import the records from your file.
For more information, including step-by-step procedures, see
- Migration Hub Import][2
-
in the *Amazon Web Services Application
Discovery Service User Guide*.
<note markdown=“1”> There are limits to the number of import tasks you can create (and delete) in an Amazon Web Services account. For more information, see
- Amazon Web Services Application Discovery Service Limits][3
-
in the
*Amazon Web Services Application Discovery Service User Guide*.
</note>
[1]: s3.us-west-2.amazonaws.com/templates-7cffcf56-bd96-4b1c-b45b-a5b42f282e46/import_template.csv [2]: docs.aws.amazon.com/application-discovery/latest/userguide/discovery-import.html [3]: docs.aws.amazon.com/application-discovery/latest/userguide/ads_service_limits.html
1739 1740 1741 1742 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1739 def start_import_task(params = {}, = {}) req = build_request(:start_import_task, params) req.send_request() end |
#stop_continuous_export(params = {}) ⇒ Types::StopContinuousExportResponse
Stop the continuous flow of agent’s discovered data into Amazon Athena.
1768 1769 1770 1771 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1768 def stop_continuous_export(params = {}, = {}) req = build_request(:stop_continuous_export, params) req.send_request() end |
#stop_data_collection_by_agent_ids(params = {}) ⇒ Types::StopDataCollectionByAgentIdsResponse
Instructs the specified agents to stop collecting data.
1797 1798 1799 1800 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1797 def stop_data_collection_by_agent_ids(params = {}, = {}) req = build_request(:stop_data_collection_by_agent_ids, params) req.send_request() end |
#update_application(params = {}) ⇒ Struct
Updates metadata about an application.
1829 1830 1831 1832 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1829 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1858 1859 1860 |
# File 'lib/aws-sdk-applicationdiscoveryservice/client.rb', line 1858 def waiter_names [] end |