Class: Aws::ApplicationDiscoveryService::Types::ExportInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationdiscoveryservice/types.rb

Overview

Information regarding the export status of discovered data. The value is an array of objects.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurations_download_urlString

A URL for an Amazon S3 bucket where you can review the exported data. The URL is displayed only if the export succeeded.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_idString

A unique identifier used to query an export.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_request_timeTime

The time that the data export was initiated.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_statusString

The status of the data export job.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#is_truncatedBoolean

If true, the export of agent information exceeded the size limit for a single export and the exported data is incomplete for the requested time range. To address this, select a smaller time range for the export by using startDate and endDate.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#requested_end_timeTime

The endTime used in the StartExportTask request. If no endTime was requested, this result does not appear in ExportInfo.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#requested_start_timeTime

The value of startTime parameter in the StartExportTask request. If no startTime was requested, this result does not appear in ExportInfo.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A status message provided for API callers.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/aws-sdk-applicationdiscoveryservice/types.rb', line 1280

class ExportInfo < Struct.new(
  :export_id,
  :export_status,
  :status_message,
  :configurations_download_url,
  :export_request_time,
  :is_truncated,
  :requested_start_time,
  :requested_end_time)
  SENSITIVE = []
  include Aws::Structure
end